@@ -280,7 +280,7 @@ class Table:
         items = response.get('Items', [])
         while 'LastEvaluatedKey' in response:
             response = self._table.scan(ExclusiveStartKey=response['LastEvaluatedKey'])
-            items.extend(response['items'])
+            items.extend(response.get('Items', []))
 
         stripped_items = [self._strip_prefixes(item) for item in items]
 
